summaryrefslogtreecommitdiffstats
path: root/karm/karmstorage.h
diff options
context:
space:
mode:
Diffstat (limited to 'karm/karmstorage.h')
-rw-r--r--karm/karmstorage.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/karm/karmstorage.h b/karm/karmstorage.h
index af2d3be0..214dab53 100644
--- a/karm/karmstorage.h
+++ b/karm/karmstorage.h
@@ -132,7 +132,7 @@ class KarmStorage
* Read tasks and their total times from a text file (legacy storage).
*
* This reads from one of the two legacy file formats. In this version,
* the parent task times do not include the sum of all their children's
* times.
*
* The format of the file is zero or more lines of:
@@ -147,7 +147,7 @@ class KarmStorage
* Reads tasks and their total times from text file (legacy).
*
* This is the older legacy format, where the task totals included the
- * children totals.
+ * tqchildren totals.
*
* @see loadFromFlatFile
*/
@@ -266,15 +266,15 @@ class KarmStorage
* Add this task from iCalendar file.
*
* Create a new KCal::Todo object and load with task information. If
* parent is not zero, then set the RELATED-TO attribute for this Todo.
*
* @param task The task to be removed.
* @param parent The parent of this task. Must have a uid() that is in
* the existing calendar. If zero, this task is considered a root task.
* @return The unique ID for the new VTODO. Return an null TQString if
* there was an error creating the new calendar object.
*/
- TQString addTask(const Task* task, const Task* parent);
+ TQString addTask(const Task* task, const Task* tqparent);
/**
* Check if the iCalendar file currently loaded has any Todos in it.
@@ -308,7 +308,7 @@ class KarmStorage
bool parseLine(TQString line, long *time, TQString *name, int *level,
DesktopList* desktopList);
TQString writeTaskAsTodo
- (Task* task, const int level, TQPtrStack< KCal::Todo >& parents);
+ (Task* task, const int level, TQPtrStack< KCal::Todo >& tqparents);
bool saveCalendar();
KCal::Event* baseEvent(const Task*);
@@ -132,7 +132,7 @@ class KarmStorage
*
* This reads from one of the two legacy file formats. In this version,
- * the parent task times do not include the sum of all their children's
+ * the tqparent task times do not include the sum of all their tqchildren's
* times.
*
@@ -266,15 +266,15 @@ class KarmStorage
*
* Create a new KCal::Todo object and load with task information. If
- * parent is not zero, then set the RELATED-TO attribute for this Todo.
+ * tqparent is not zero, then set the RELATED-TO attribute for this Todo.
*
* @param task The task to be removed.
@@ -266,15 +266,15 @@ class KarmStorage
*
* @param task The task to be removed.
- * @param parent The parent of this task. Must have a uid() that is in
+ * @param tqparent The tqparent of this task. Must have a uid() that is in
* the existing calendar. If zero, this task is considered a root task.
* @return The unique ID for the new VTODO. Return an null TQString if